(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     17156,        468]
NotebookOptionsPosition[     16056,        427]
NotebookOutlinePosition[     16692,        451]
CellTagsIndexPosition[     16649,        448]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Roofing a Cube to Produce a Dodecahedron", "Section",
 CellFrameColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108],
 FontColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"cub", "=", 
     RowBox[{
      RowBox[{"PolyhedronData", "[", "\"\<Cube\>\"", "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"vA", "=", 
     RowBox[{"{", 
      RowBox[{".5", ",", ".5", ",", 
       RowBox[{".5", "+", "a"}]}], "}"}]}], ";", " ", 
    RowBox[{"vB", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", ".5"}], ",", ".5", ",", 
       RowBox[{".5", "+", "a"}]}], "}"}]}], ";", 
    RowBox[{"vC", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", ".5"}], ",", 
       RowBox[{"-", ".5"}], ",", 
       RowBox[{".5", "+", "a"}]}], "}"}]}], ";", 
    RowBox[{"vD", "=", 
     RowBox[{"{", 
      RowBox[{".5", ",", 
       RowBox[{"-", ".5"}], ",", 
       RowBox[{".5", "+", "a"}]}], "}"}]}], ";", 
    RowBox[{"vE", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{".5", "/", "GoldenRatio"}], ",", "0", ",", 
       RowBox[{
        RowBox[{".5", " ", "GoldenRatio"}], "+", "a"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"vF", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", ".5"}], "/", " ", "GoldenRatio"}], ",", "0", ",", 
       RowBox[{
        RowBox[{".5", " ", "GoldenRatio"}], "+", "a"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"square", "=", 
     RowBox[{"Polygon", "[", 
      RowBox[{"{", 
       RowBox[{"vA", ",", "vB", ",", "vC", ",", "vD"}], "}"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"tri1", "=", 
     RowBox[{"Polygon", "[", 
      RowBox[{"{", 
       RowBox[{"vD", ",", "vA", ",", "vE"}], "}"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"tri2", "=", 
     RowBox[{"Polygon", "[", 
      RowBox[{"{", 
       RowBox[{"vB", ",", "vC", ",", "vF"}], "}"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"tra1", "=", 
     RowBox[{"Polygon", "[", 
      RowBox[{"{", 
       RowBox[{"vA", ",", "vB", ",", "vF", ",", "vE"}], "}"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"tra2", "=", 
     RowBox[{"Polygon", "[", 
      RowBox[{"{", 
       RowBox[{"vC", ",", "vD", ",", "vE", ",", "vF"}], "}"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"r0", "=", 
     RowBox[{"{", 
      RowBox[{"square", ",", "tri1", ",", "tri2", ",", "tra1", ",", "tra2"}], 
      "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"r1", "=", 
     RowBox[{"Rotate", "[", 
      RowBox[{"r0", ",", "turn", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", ".5"}], ",", "0", ",", 
         RowBox[{".5", "+", "a"}]}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"r2", "=", 
     RowBox[{"Rotate", "[", 
      RowBox[{"r1", ",", "Pi", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "]"}]}], ";", 
    RowBox[{"r3", "=", 
     RowBox[{"{", 
      RowBox[{"r1", ",", "r2"}], "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"r4", "=", 
     RowBox[{"Rotate", "[", 
      RowBox[{
       RowBox[{"Rotate", "[", 
        RowBox[{"r3", ",", 
         RowBox[{"Pi", "/", "2"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}], ",", 
       RowBox[{"Pi", "/", "2"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"r5", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Opacity", "[", "op", "]"}], ",", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Rotate", "[", 
          RowBox[{"r3", ",", 
           RowBox[{"Pi", "/", "2"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"Pi", "/", "2"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "]"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Opacity", "[", "0.25", "]"}], ",", 
          RowBox[{"RGBColor", "[", 
           RowBox[{".67", ",", ".75", ",", ".15"}], "]"}], ",", "cub"}], 
         "}"}], ",", "r3", ",", "r4", ",", "r5"}], "}"}], ",", 
      RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
      RowBox[{"SphericalRegion", "\[Rule]", "True"}], ",", 
      RowBox[{"ViewAngle", "\[Rule]", 
       RowBox[{"Pi", "/", "14"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"1.8", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}]}]}], "]"}]}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "0.3", ",", "\"\<elevate roofs\>\""}], "}"}], ",", 
     "0", ",", "0.6"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"turn", ",", "0", ",", "\"\<turn roofs\>\""}], "}"}], ",", "0", 
     ",", 
     RowBox[{"-", "Pi"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"op", ",", "1", ",", "\"\<opacity of 2 roofs\>\""}], "}"}], ",",
      "0", ",", "1"}], "}"}], ",", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "turn", ",", "op"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.384661986140625*^9, 3.384662122578125*^9}, {
  3.384662157578125*^9, 3.38466234575*^9}, {3.384662417015625*^9, 
  3.38466244378125*^9}, {3.384662492375*^9, 3.384662913734375*^9}, {
  3.384663075453125*^9, 3.3846632788125*^9}, {3.3846633329375*^9, 
  3.3846633375*^9}, {3.384663374640625*^9, 3.384663380171875*^9}, {
  3.384663462609375*^9, 3.384663467875*^9}, {3.38466352125*^9, 
  3.384663745078125*^9}, {3.384663849703125*^9, 3.384663863578125*^9}, {
  3.3846642045625*^9, 3.38466425775*^9}, {3.38466429453125*^9, 
  3.384664302234375*^9}, {3.384664335890625*^9, 3.38466439278125*^9}, {
  3.3846644365*^9, 3.384664437515625*^9}, {3.384664552703125*^9, 
  3.384664555578125*^9}, {3.384664645421875*^9, 3.38466465325*^9}, {
  3.384664797046875*^9, 3.3846647984375*^9}, {3.384664864046875*^9, 
  3.384664946390625*^9}, {3.384665004640625*^9, 3.384665031625*^9}, {
  3.38466507275*^9, 3.384665073625*^9}, {3.38466511934375*^9, 
  3.384665120609375*^9}, {3.384666452203125*^9, 3.384666454953125*^9}, {
  3.384666637640625*^9, 3.384666722671875*^9}, {3.3846668204375*^9, 
  3.38466687609375*^9}, {3.384667163359375*^9, 3.38466718265625*^9}, {
  3.3846888982283926`*^9, 3.3846889006419134`*^9}},
 CellID->39288151],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.3, $CellContext`op$$ = 
    1, $CellContext`turn$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.3, "elevate roofs"}, 0, 0.6}, {{
       Hold[$CellContext`turn$$], 0, "turn roofs"}, 0, -Pi}, {{
       Hold[$CellContext`op$$], 1, "opacity of 2 roofs"}, 0, 1}}, 
    Typeset`size$$ = {360., {178., 182.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True, $CellContext`a$412$$ = 
    0, $CellContext`turn$417$$ = 0, $CellContext`op$418$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.3, $CellContext`op$$ = 
        1, $CellContext`turn$$ = 0}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$412$$, 0], 
        Hold[$CellContext`turn$$, $CellContext`turn$417$$, 0], 
        Hold[$CellContext`op$$, $CellContext`op$418$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ($CellContext`cub = Part[
          PolyhedronData["Cube"], 1]; $CellContext`vA = {
         0.5, 0.5, 0.5 + $CellContext`a$$}; $CellContext`vB = {-0.5, 0.5, 
          0.5 + $CellContext`a$$}; $CellContext`vC = {-0.5, -0.5, 
          0.5 + $CellContext`a$$}; $CellContext`vD = {
         0.5, -0.5, 0.5 + $CellContext`a$$}; $CellContext`vE = {
         0.5/GoldenRatio, 0, 
          0.5 GoldenRatio + $CellContext`a$$}; $CellContext`vF = {(-0.5)/
          GoldenRatio, 0, 
          0.5 GoldenRatio + $CellContext`a$$}; $CellContext`square = 
        Polygon[{$CellContext`vA, $CellContext`vB, $CellContext`vC, \
$CellContext`vD}]; $CellContext`tri1 = 
        Polygon[{$CellContext`vD, $CellContext`vA, $CellContext`vE}]; \
$CellContext`tri2 = 
        Polygon[{$CellContext`vB, $CellContext`vC, $CellContext`vF}]; \
$CellContext`tra1 = 
        Polygon[{$CellContext`vA, $CellContext`vB, $CellContext`vF, \
$CellContext`vE}]; $CellContext`tra2 = 
        Polygon[{$CellContext`vC, $CellContext`vD, $CellContext`vE, \
$CellContext`vF}]; $CellContext`r0 = {$CellContext`square, $CellContext`tri1, \
$CellContext`tri2, $CellContext`tra1, $CellContext`tra2}; $CellContext`r1 = 
        Rotate[$CellContext`r0, $CellContext`turn$$, {1, 0, 
          0}, {-0.5, 0, 0.5 + $CellContext`a$$}]; $CellContext`r2 = 
        Rotate[$CellContext`r1, Pi, {1, 0, 
          0}]; $CellContext`r3 = {$CellContext`r1, $CellContext`r2}; \
$CellContext`r4 = Rotate[
          Rotate[$CellContext`r3, Pi/2, {0, 0, 1}], Pi/2, {0, 1, 
          0}]; $CellContext`r5 = {
          Opacity[$CellContext`op$$], 
          Rotate[
           Rotate[$CellContext`r3, Pi/2, {0, 0, 1}], Pi/2, {1, 0, 0}]}; 
       Graphics3D[{{
           Opacity[0.25], 
           RGBColor[
           0.67, 0.75, 
            0.15], $CellContext`cub}, $CellContext`r3, $CellContext`r4, \
$CellContext`r5}, Boxed -> False, SphericalRegion -> True, ViewAngle -> Pi/14,
          PlotRange -> 1.8 {{-1, 1}, {-1, 1}, {-1, 1}}]), 
      "Specifications" :> {{{$CellContext`a$$, 0.3, "elevate roofs"}, 0, 
         0.6}, {{$CellContext`turn$$, 0, "turn roofs"}, 0, -
         Pi}, {{$CellContext`op$$, 1, "opacity of 2 roofs"}, 0, 1}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`a$$, $CellContext`turn$$, \
$CellContext`op$$}}, "DefaultOptions" :> {}],
     ImageSizeCache->{403., {249.84375, 255.15625}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.413128717177452*^9}]
}, {2}]]
}, Open  ]],

Cell[CellGroupData[{

Cell["THIS NOTEBOOK IS THE SOURCE CODE FROM", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "\"",
 ButtonBox["Roofing a Cube to Produce a Dodecahedron",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/RoofingACubeToProduceADodecahedron/\
"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/RoofingACubeToProduceADodecahedron/"],
 "\"",
 " from ",
 ButtonBox["The Wolfram Demonstrations Project",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
 "\[ParagraphSeparator]\[NonBreakingSpace]",
 ButtonBox["http://demonstrations.wolfram.com/\
RoofingACubeToProduceADodecahedron/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/RoofingACubeToProduceADodecahedron/\
"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/RoofingACubeToProduceADodecahedron/"]
}], "Text",
 CellMargins->{{48, Inherited}, {0, Inherited}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.5]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" ", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell["Contributed by: S\[AAcute]ndor Kabai", "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{66, 48}, {2, 4}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.6]],

Cell[TextData[{
 "A full-function Wolfram ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 6 system is required to edit or run this notebook.\[IndentingNewLine](",
 StyleBox["Mathematica Player",
  FontSlant->"Italic"],
 " runs only Demonstrations published on this site.)\n",
 StyleBox[ButtonBox["GET WOLFRAM MATHEMATICA 6 \[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/products/mathematica/"], None},
  ButtonNote->"http://www.wolfram.com/products/mathematica/"],
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.42, 0]]
}], "Text",
 CellFrame->True,
 CellMargins->{{48, 68}, {8, 28}},
 CellFrameMargins->12,
 CellFrameColor->RGBColor[0.865507, 0.90634, 0.680751],
 CellChangeTimes->{3.3750111182355957`*^9},
 ParagraphSpacing->{1., 1.},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.411765],
 Background->RGBColor[0.986023, 0.991363, 0.969818]],

Cell[TextData[{
 "\[Copyright] ",
 StyleBox[ButtonBox["The Wolfram Demonstrations Project & Contributors",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Terms of Use",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/termsofuse.html"], None},
  ButtonNote->"http://demonstrations.wolfram.com/termsofuse.html"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Make a new version of this Demonstration \
\[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/participate/upload.jsp?id=\
RoofingACubeToProduceADodecahedron"], None},
  ButtonNote->None],
  FontColor->GrayLevel[0.6]]
}], "Text",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellMargins->{{48, 10}, {20, 50}},
 CellFrameMargins->{{6, 0}, {6, 6}},
 CellFrameColor->GrayLevel[0.6],
 FontFamily->"Verdana",
 FontSize->9,
 FontColor->GrayLevel[0.6]]
}, Open  ]]
},
ClosingSaveDialog->False,
Editable->True,
ScreenStyleEnvironment->"Working",
WindowSize->{710, 650},
WindowMargins->{{Inherited, Inherited}, {Inherited, 0}},
WindowElements->{
 "StatusArea", "MemoryMonitor", "MagnificationPopUp", "VerticalScrollBar", 
  "MenuBar"},
WindowTitle->"Roofing a Cube to Produce a Dodecahedron - Source",
DockedCells->{},
CellContext->Notebook,
FrontEndVersion->"6.1 for Mac OS X x86 (32-bit) (January 25, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 232, 4, 67, "Section"],
Cell[CellGroupData[{
Cell[824, 30, 6896, 182, 313, "Input",
 CellID->39288151],
Cell[7723, 214, 4143, 79, 523, "Output"]
}, {2}]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11912, 299, 373, 9, 50, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[12288, 310, 1001, 29, 35, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13326, 344, 337, 9, 50, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[13666, 355, 191, 5, 18, "Text"],
Cell[13860, 362, 967, 27, 113, "Text"],
Cell[14830, 391, 1210, 33, 88, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
